#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from __future__ import annotations

from typing import TYPE_CHECKING, Protocol

if TYPE_CHECKING:
    import argparse
    from typing import Type

    from modplanner.main import ModplannerCommand
    from modplanner.config.settings import Settings


_commands: dict[str, Type[ModplannerCommand]] = {}


def modplanner_command(name: str):

    def _fn(cmd: Type[ModplannerCommand]) -> Type[ModplannerCommand]:
        _commands[name] = cmd
        return cmd

    return _fn


def get_commands():
    return [(k, v()) for k, v in _commands.items()]


def get_command(name: str) -> ModplannerCommand:
    if name not in _commands:
        raise ValueError(f"Unknown command {name}.")
    return _commands[name]()


class Subcommand(Protocol):

    def __init__(self, namespace: argparse.Namespace) -> None: ...
    def run(self, settings: Settings) -> None: ...
