#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


"""
Simple utilities to prompt for the confirmation of a certain operation batch
execution.

This code will likely be changed, and nothing of interest happens here.
"""


from __future__ import annotations

from typing import TYPE_CHECKING

from modplanner.tty import tty, operations

if TYPE_CHECKING:
    from modplanner.cli.stage import Stage


def print_operations(stage: Stage) -> None:
    assert stage.operations is not None
    tty.print("=" * 20 + " " + stage.name + " " + "=" * 20, bold=True)
    tty.print("Queued operations:", bold=True)
    operations.print_operations(stage.operations)


def confirm_stage(stage: Stage) -> bool:
    if stage.operations is not None:
        print_operations(stage)
        return (
            tty.prompt("❯ Confirm these operations?", choices=["y", "n"]).lower() == "y"
        )
    return True
