#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from typing import Callable

from modplanner.tty import tty

from filetree.operations import ExecutableBatch

OperationsFactory = Callable[[], ExecutableBatch]


class Stage:
    """
    Simple object representing a single stage of operations.

    This is manly a utility to simplify the logical separation of
    different operation batches and their representation on the tty prompt.
    """

    def __init__(
        self, name: str, operations_factory: OperationsFactory, *, stage: bool = False
    ) -> None:
        self.name = name
        self._factory = operations_factory
        self.operations: ExecutableBatch | None = None
        if stage:
            self.stage_operations()

    def stage_operations(self) -> None:
        self.operations = self._factory()
        self.operations.sort()

    def __bool__(self) -> bool:
        return bool(self.operations)

    def execute(self) -> None:
        tty.debug(f"Executing operations for stage: {self.name}")
        if self.operations is None:
            return
        self.operations.execute()
