#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from __future__ import annotations

from typing import TYPE_CHECKING

from modplanner.tty import tty
from modplanner.plugins.spack.index import ModuleIndex
from modplanner.utils import load_yaml

if TYPE_CHECKING:
    from filetree import PathLike

    from modplanner import module


class ModuleIndexRepo:
    """
    Simple implementation of `SpackModuleRepo` using a `ModuleIndex` object,
    sourced from a `module-index.yaml` file, as the source of information.
    """

    def __init__(self, index: ModuleIndex) -> None:
        self._index = index

    @classmethod
    def from_path(cls, index_path: PathLike) -> ModuleIndexRepo:
        tty.debug(f"Loading module index from {index_path}")
        module_index = ModuleIndex.from_dict(load_yaml(index_path))
        return cls(index=module_index)

    def get_module(self, hash: str) -> module.Module | None:
        return self._index.get(hash)
