#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from __future__ import annotations

import sys
import importlib
from pathlib import Path
from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from filetree import PathLike

    from modplanner.plugins.spack.spec_repo import SpackSpec


def initialize(spack_root: PathLike) -> None:
    spack_root = Path(spack_root).absolute()

    spack_lib_path = spack_root / "lib" / "spack"
    vendoring_lib_path = spack_root / "lib" / "spack" / "external" / "_vendoring"
    external_lib_path = spack_root / "lib" / "spack" / "external"

    sys.path.insert(0, str(spack_lib_path))
    sys.path.insert(0, str(vendoring_lib_path))
    sys.path.insert(0, str(external_lib_path))
    importlib.import_module("spack.main")


class DBRepo:

    def __init__(self, db) -> None:
        self._db = db

    @classmethod
    def from_paths(cls, install_root: PathLike, spack_root: PathLike) -> DBRepo:
        install_root = Path(install_root).absolute()

        initialize(spack_root=spack_root)

        db_module = importlib.import_module(".database", "spack")
        db_instance = db_module.Database(root=install_root)

        return cls(db=db_instance)

    def implicit_specs(self) -> list[SpackSpec]:
        return self._db.query(explicit=False)

    def specs_from_constraint(self, constraint: str) -> list[SpackSpec]:
        return self._db.query(constraint)
