#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from __future__ import annotations

from typing import TYPE_CHECKING

from rich.text import Text

from modplanner.module import Packages
from modplanner.tty import tree, tty
from modplanner.service.dispatch import get_mappings_dict

if TYPE_CHECKING:
    from collections import OrderedDict
    from typing import Iterable

    from modplanner.service.map.context import ModuleContext
    from modplanner.module import Module


def print_mappings(
    module_context: ModuleContext, ordered_mappings: OrderedDict[str, set[str]]
):

    def _callback(module, active_mappings):
        if module_context.hide_ctx.is_hidden(module, context=active_mappings):
            return Text(module.module_name, style="grey53")
        return module.module_name

    tree_dict = get_mappings_dict(
        module_context=module_context,
        ordered_mappings=ordered_mappings,
        callback=_callback,
    )
    printable = tree.pretty_print_tree(tree_dict)
    tty.print_renderable(printable, indentation=4)


def print_flat(modules: Iterable[Module]) -> None:
    _dict = {
        k: [m.module_name for m in v] for k, v in Packages.from_modules(modules).items()
    }
    printable = tree.pretty_print_tree(_dict)
    tty.print_renderable(printable, indentation=4)
