#
# Author: Francesco Talpo
#
# This file is part of Modplanner.
#
# Modplanner is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation, either version 3 of the License,
# or (at your option) any later version.
#
# Modplanner is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Modplanner. If not, see <https://www.gnu.org/licenses/>.
#


from __future__ import annotations

from rich.tree import Tree
from rich.text import Text


def pretty_print_tree(data: dict, tree: Tree | None = None, level=0) -> Tree:
    COLORS = ["dodger_blue2", "green", "purple"]

    if level == 0:
        tree = Tree("Defaults", hide_root=True)

    assert tree is not None

    try:
        color = COLORS[level]
    except IndexError:
        color = None

    for key, values in data.items():
        key = Text(key, style=f"bold {color}")
        branch = tree.add(key)
        if isinstance(values, dict):
            pretty_print_tree(values, branch, level + 1)
        else:
            for value in values:
                branch.add(value)

    return tree
