from pathlib import Path

from modplanner.config.factories import EngineCallbackFactory
from modplanner.module import Module
from modplanner.service.map.context import ModuleContext


def module_ctx(params):
    ctx = ModuleContext()
    fct = EngineCallbackFactory(ctx)
    module = Module("pack1", path=Path("path1"))
    cb = fct.create_action("conditional_hide", params)
    cb(module)
    return module, ctx


class TestConditionalHide:

    def test_not_hidden_without_ctx_mapped(self):
        module, ctx = module_ctx({"mapped": {"a": ["b"]}})
        assert not ctx.hide_ctx.is_hidden(module)

    def test_not_hidden_without_ctx_not_mapped(self):
        module, ctx = module_ctx({"not_mapped": {"a": ["b"]}})
        assert not ctx.hide_ctx.is_hidden(module)

    def test_not_hidden_without_ctx_both(self):
        module, ctx = module_ctx({"mapped": {"a": ["b"]}, "not_mapped": {"a": ["c"]}})
        assert not ctx.hide_ctx.is_hidden(module)

    def test_hidden_with_ctx_mapped(self):
        module, ctx = module_ctx({"mapped": {"a": ["b"]}})
        assert ctx.hide_ctx.is_hidden(module, context={"a": "b"})

    def test_hidden_with_ctx_not_mapped(self):
        module, ctx = module_ctx({"not_mapped": {"a": ["c"]}})
        assert ctx.hide_ctx.is_hidden(module, context={"a": "b"})

    def test_hidden_with_ctx_both(self):
        module, ctx = module_ctx({"mapped": {"a": ["b"]}, "not_mapped": {"a": ["c"]}})
        assert ctx.hide_ctx.is_hidden(module, context={"a": "b"})

    def test_not_hidden_wrong_ctx(self):
        module, ctx = module_ctx({"mapped": {"a": ["b"]}})
        assert not ctx.hide_ctx.is_hidden(module, context={"a": "c"})
