import pytest

from filetree.fsentry import File, Symlink
from filetree.service.tree import FiletreeBuilder

from modplanner.module import Module
from modplanner.service.dispatch import (
    packages_from_modules,
    dispatch_modules_flat,
    LINK,
    COPY,
)

from pathlib import Path


@pytest.fixture
def modules():
    return [
        Module("pack1", Path("path1")),
        Module("pack2", Path("path2")),
        Module("pack3", Path("path3")),
    ]


def test_packages(modules):
    packs = packages_from_modules(modules)
    assert packs == {
        "pack1": {Module("pack1", Path("path1"))},
        "pack2": {Module("pack2", Path("path2"))},
        "pack3": {Module("pack3", Path("path3"))},
    }


def test_deploy_flat(modules):
    bld = FiletreeBuilder()
    root = bld.build_dir("/")
    bld.set_root(root)
    bld = dispatch_modules_flat(bld, root, modules)
    tree = bld.build()

    for num in "1", "2", "3":
        assert tree.get_path("/pack" + num) is not None
        assert tree.get_path("/pack" + num + "/path" + num) is not None


def test_link_strategy(modules):
    bld = FiletreeBuilder()
    root = bld.build_dir("/")
    bld.set_root(root)
    bld = dispatch_modules_flat(bld, root, modules, strategy=LINK)
    tree = bld.build()

    for num in "1", "2", "3":
        assert isinstance(tree.get_path("/pack" + num + "/path" + num).entry, Symlink)


def test_copy_strategy(modules):
    bld = FiletreeBuilder()
    root = bld.build_dir("/")
    bld.set_root(root)
    bld = dispatch_modules_flat(bld, root, modules, strategy=COPY)
    tree = bld.build()

    for num in "1", "2", "3":
        assert isinstance(tree.get_path("/pack" + num + "/path" + num).entry, File)
