from ast import Call
from pathlib import Path

from modplanner.service.map.engine import CallbackEngine
from modplanner.module import Module


import pytest


class AllFilter:

    def __call__(self, module: Module) -> bool:
        return True


class Callback:

    def __init__(self) -> None:
        self.seen: set[Module] = set()

    def __call__(self, module: Module) -> None:
        self.seen.add(module)


@pytest.fixture
def mods():
    return [
        Module("pack1", Path("path1")),
        Module("pack2", Path("path2")),
        Module("pack3", Path("path3")),
    ]


def test_engine_registers_callbacks():
    engine = CallbackEngine([])
    cb = lambda m, ctx: None
    engine.register_callback(cb)
    assert cb in engine._callbacks


def test_engine_calls_all_callbacks(mods):
    cb = Callback()
    engine = CallbackEngine([AllFilter()])
    engine.register_callback(cb)
    engine.apply(mods)
    assert cb.seen == set(mods)


class NarrowFilter:
    def __init__(self, name: str) -> None:
        self.name = name

    def __call__(self, module: Module) -> bool:
        return module.package_name == self.name


def test_engine_calls_callbacks_filtered(mods):
    cb = Callback()
    engine = CallbackEngine([NarrowFilter("pack1")])
    engine.register_callback(cb)
    engine.apply(mods)
    assert cb.seen == {mods[0]}
