from pathlib import Path

from modplanner.service.map.filter import PackageNameFilter, NamePatternFilter
from modplanner.module import Module

import pytest


@pytest.fixture
def package_filter():
    return PackageNameFilter(["name1", "name2"])


def module(name: str):
    return Module(name, Path("/path"))


def test_package_name_filter_negative(package_filter):
    mod = module("name3")
    assert not package_filter(mod)


def test_package_name_filter_positive(package_filter):
    mod = module("name1")
    assert package_filter(mod)


@pytest.fixture
def name_pattern():
    return NamePatternFilter(["foo"])


def test_name_pattern_filter_negative(name_pattern):
    mod = module("not matching")
    assert not name_pattern(mod)


def test_name_pattern_filter_positive_entire(name_pattern):
    mod = module("foo")
    assert name_pattern(mod)


def test_name_pattern_filter_positive_partial(name_pattern):
    mod = module("foomodulename")
    assert name_pattern(mod)
