from modplanner.utils import Version

import pytest


@pytest.mark.parametrize("version", ["1", "0.1", "1.0", "0.0.1", "1.0.0"])
def test_eq_same_length(version):
    assert Version(version) == version


@pytest.mark.parametrize("one, two", [("1", "1.0"), ("0", "0.0"), ("1.1", "1.1.0")])
def test_eq_different_length(one, two):
    assert Version(one) == two


@pytest.mark.parametrize("one, two", [("0", "1"), ("0.0", "0.1"), ("1.0.0", "1.0.1")])
def test_lt_same_length(one, two):
    assert Version(one) < two


@pytest.mark.parametrize("one, two", [("1", "1.1"), ("0", "0.1"), ("1.1", "1.1.1")])
def test_lt_different_length(one, two):
    assert Version(one) < two


@pytest.mark.parametrize("one, two", [("1", "0"), ("0.1", "0.0"), ("1.0.1", "1.0.0")])
def test_gt_same_length(one, two):
    assert Version(one) > two


@pytest.mark.parametrize("one, two", [("1.1", "1"), ("0.1", "0"), ("1.1.1", "1.1")])
def test_gt_different_length(one, two):
    assert Version(one) > two


@pytest.mark.parametrize(
    "one, two",
    [
        ("1", "1"),
        ("1", "2"),
        ("0.0", "0.0"),
        ("0.0", "0.1"),
        ("0.0.0", "0.0.0"),
        ("0.0.0", "0.0.1"),
    ],
)
def test_le_same_length(one, two):
    assert Version(one) <= two


@pytest.mark.parametrize(
    "one, two",
    [
        ("1", "1.0"),
        ("1", "1.1"),
        ("0.0", "0.0.0"),
        ("0.0", "0.0.1"),
    ],
)
def test_le_different_length(one, two):
    assert Version(one) <= two


@pytest.mark.parametrize(
    "one, two",
    [
        ("1", "1"),
        ("2", "1"),
        ("0.0", "0.0"),
        ("0.1", "0.0"),
        ("0.0.0", "0.0.0"),
        ("0.0.1", "0.0.0"),
    ],
)
def test_ge_same_length(one, two):
    assert Version(one) >= two


@pytest.mark.parametrize(
    "one, two",
    [
        ("1.0", "1"),
        ("1.1", "1"),
        ("0.0.0", "0.0"),
        ("0.0.1", "0.0"),
    ],
)
def test_ge_different_length(one, two):
    assert Version(one) >= two
